"""BlackBox Schemas - Consolidated Pydantic v2 models for BlackBox LLM operations"""

# This file is auto-generated by the create_and_publish_package.sh script
# Compatible with Pydantic v2.x

# Import all models directly from models module to make them available at package level
from .models import (
    CategoryEvaluation,
    ContentGenerationSection,
    ContentGenerationSubsection,
    CostFormatingSections,
    CostImageCalculationResult,
    CostSection,
    CostSubSection,
    CostSummarySection,
    GuidanceAndClarifications,
    HourlyJobTitleWages,
    HourlySection,
    InfrastructureItem,
    InfrastructureSummary,
    JobTitle,
    LegalAdministrativeRequirements,
    License,
    LicenseList,
    PageReferences,
    PromptSection,
    PromptSubSection,
    RFPAnalysisOutput,
    RFPEvaluation,
    Recommendation,
    RfpCompanyData,
    RfpCompanyDataSection,
    RfpSection,
    RfpSummary,
    SubmissionDetails,
    TOCSection,
    TOCSubSection,
    TableOfContents,
    TechnicalOperationalRequirements,
    UserPreferences,
    UserPreferencesSection,
)

__version__ = "2.0.6"

__all__ = [
    "CategoryEvaluation",
    "ContentGenerationSection",
    "ContentGenerationSubsection",
    "CostFormatingSections",
    "CostImageCalculationResult",
    "CostSection",
    "CostSubSection",
    "CostSummarySection",
    "GuidanceAndClarifications",
    "HourlyJobTitleWages",
    "HourlySection",
    "InfrastructureItem",
    "InfrastructureSummary",
    "JobTitle",
    "LegalAdministrativeRequirements",
    "License",
    "LicenseList",
    "PageReferences",
    "PromptSection",
    "PromptSubSection",
    "RFPAnalysisOutput",
    "RFPEvaluation",
    "Recommendation",
    "RfpCompanyData",
    "RfpCompanyDataSection",
    "RfpSection",
    "RfpSummary",
    "SubmissionDetails",
    "TOCSection",
    "TOCSubSection",
    "TableOfContents",
    "TechnicalOperationalRequirements",
    "UserPreferences",
    "UserPreferencesSection",
]
